<?php
/**
 * カスタマイザーの設定
 */
if ( !defined( 'ABSPATH' ) ) {
  exit;
}

if( !function_exists( 'nmd_customizer_register_post' ) ) {
	function nmd_customizer_register_post( $wp_customize ) {
		/**
		 * パネルの追加 =========================================================
		 */
		$wp_customize->add_panel( 'nmd_postpage_panel', array(
			'title'		=> '[Nomad]投稿・固定ページの設定',
			'priority'	=> 190,
		));
		/**
		 * パンくずリストの設定
		 */
		$wp_customize->add_section( 'nmd_section_breadcrumbs', array(
			'title'	=> 'パンくずリストの設定',
			'panel'	=> 'nmd_postpage_panel',
		) );
		$wp_customize->add_setting( 'nmd_hide_breadcrumbs_post', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_hide_breadcrumbs_post', array(
			'label'		=> '投稿ページのパンくずリストを非表示にする',
			'section'	=> 'nmd_section_breadcrumbs',
			'settings'	=> 'nmd_hide_breadcrumbs_post',
			'type'		=> 'checkbox',
		) );
		$wp_customize->selective_refresh->add_partial( 'nmd_hide_breadcrumbs_post', array(
			'selector' => '#breadcrumbs',
		) );
		$wp_customize->add_setting( 'nmd_hide_breadcrumbs_page', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_hide_breadcrumbs_page', array(
			'label'		=> '固定ページのパンくずリストを非表示にする',
			'section'	=> 'nmd_section_breadcrumbs',
			'settings'	=> 'nmd_hide_breadcrumbs_page',
			'type'		=> 'checkbox',
		) );
		$wp_customize->selective_refresh->add_partial( 'nmd_hide_breadcrumbs_page', array(
			'selector' => '#breadcrumbs-page',
		) );
		$wp_customize->add_setting( 'nmd_hide_breadcrumbs_cat', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_hide_breadcrumbs_cat', array(
			'label'		=> 'カテゴリーページのパンくずリストを非表示にする',
			'section'	=> 'nmd_section_breadcrumbs',
			'settings'	=> 'nmd_hide_breadcrumbs_cat',
			'type'		=> 'checkbox',
		) );
		/**
		 * 目次設定
		 */
		$wp_customize->add_section( 'nmd_toc_section', array(
			'title'			=> '目次設定',
			'panel'			=> 'nmd_postpage_panel',
			'description'	=> '記事内に表示させる目次の設定。'
		) );
		$wp_customize->add_setting( 'nmd_toc_setting_title', array(
			'sanitize_callback' => 'nmd_no_sanitize',
		) );
		$wp_customize->add_control( new Nmd_Custom_Title( $wp_customize, 'nmd_toc_setting_title', array(
			'section' => 'nmd_toc_section',
			'label'   => '目次の設定',
		) ) );

		$wp_customize->add_setting( 'nmd_toc_auto', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_toc_auto', array(
			'section'		=> 'nmd_toc_section',
			'settings'		=> 'nmd_toc_auto',
			'label'			=> '目次を自動表示',
			'description'	=> '投稿ページに自動で目次を表示。<br>[toc]ショートコードがあればその位置に。なければ一番最初の見出しの上に自動表示。<br>個別記事で表示・非表示を切り替えることもできます。',
			'type'			=> 'checkbox',
		) );
		$wp_customize->add_setting( 'nmd_toc_numbering', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_toc_numbering', array(
			'section'	=> 'nmd_toc_section',
			'settings'	=> 'nmd_toc_numbering',
			'label'		=> '目次に番号を振る',
			'type'		=> 'checkbox',
		) );
		
		$wp_customize->add_setting( 'nmd_toc_number', array(
			'default'			=> '1',
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_number_range',
		) );
		$wp_customize->add_control( 'nmd_toc_number', array(
			'section'		=> 'nmd_toc_section',
			'settings'		=> 'nmd_toc_number',
			'description'	=> '目次を表示するための最小見出し数を指定',
			'type'			=> 'number',
			'input_attrs'	=> array(
				'step' => '1',
				'min'  => '1',
				'max'  => '20',
			),
			) );
		// 表示する見出しの深さ
		$wp_customize->add_setting( 'nmd_toc_heading_num', array(
			'default'			=> '4',
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_select',
		) );
		$wp_customize->add_control( 'nmd_toc_heading_num', array(
			'section'		=> 'nmd_toc_section',
			'settings'		=> 'nmd_toc_heading_num',
			'description'	=> 'どの見出しまで目次に含めるか',
			'type'			=> 'select',
			'choices'     	=> array(
				'2' => 'h2まで',
				'3' => 'h3まで',
				'4' => 'h4まで',
				'5' => 'h5まで',
				'6' => 'h6まで',
			),
		) );
		// 目次パネルデフォルト設定
		$wp_customize->add_setting('nmd_toc_close', array( 
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control('nmd_toc_close', array( 
			'section' 	=> 'nmd_toc_section', 
			'settings'	=> 'nmd_toc_close', 
			'label'     => '目次をデフォルトで閉じておく',
			'type'      => 'checkbox',
		) );
		$wp_customize->add_setting( 'nmd_toc_title', array(
			'type'				=> 'option',
			'default'			=> '目次',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'nmd_toc_title', array(
			'label'			=> '目次のタイトル',
			'description'	=> '目次のタイトルを入力してください。',
			'section'		=> 'nmd_toc_section',
			'settings'		=> 'nmd_toc_title',
			'type'			=> 'text',
		) );
		/**
		 * 見出しのデザイン
		 */
		$wp_customize->add_section( 'section_heading', array(
			'title'			=> '見出しのデザイン',
			'panel'			=> 'nmd_postpage_panel',
			'description'	=> '見出しのデザインを設定します'
		) );
		$wp_customize->add_setting( 'nmd_heading_h2', array(
			'type'				=> 'option',
			'default'			=> 'default',
			'sanitize_callback'	=> 'nmd_sanitize_select',
		) );
		$wp_customize->add_control( 'nmd_heading_h2', array(
			'label'		=> '記事内h2見出しのスタイル',
			'section'	=> 'section_heading',
			'settings'	=> 'nmd_heading_h2',
			'type'		=> 'select',
			'choices'	=> array(
				'default' => '装飾なし',
				'bg-color' => '背景カラー',
				'left-line' => '左線',
				'left-line-bg-color' => '左線＋背景色',
				'under-line' => '下線',
				'top-under-line' => '上線＋下線',
				'arrow' => '矢印＋サークル',
				'double-line' => '二重線',
				'marker' => 'マーカー',
				'fold' => '折込み',
				'speech-bubble' => '吹き出し＋背景色',
				'speech-bubble-border'=> '吹き出し＋枠線',
				'speech-bubble-under-line'=> '吹き出し＋下線',
				'brackets'=> '括弧',
			),
		) );
		$wp_customize->add_setting( 'nmd_heading_h3', array(
			'type'				=> 'option',
			'default'			=> 'default',
			'sanitize_callback'	=> 'nmd_sanitize_select',
		) );
		$wp_customize->add_control( 'nmd_heading_h3', array(
			'label'		=> '記事内h3見出しのスタイル',
			'section'	=> 'section_heading',
			'settings'	=> 'nmd_heading_h3',
			'type'		=> 'select',
			'choices'	=> array(
				'default' => '装飾なし',
				'bg-color' => '背景カラー',
				'left-line' => '左線',
				'left-line-bg-color' => '左線＋背景色',
				'under-line' => '下線',
				'top-under-line' => '上線＋下線',
				'arrow' => '矢印＋サークル',
				'double-line' => '二重線',
				'marker' => 'マーカー',
				'fold' => '折込み',
				'speech-bubble' => '吹き出し＋背景色',
				'speech-bubble-border'=> '吹き出し＋枠線',
				'speech-bubble-under-line'=> '吹き出し＋下線',
				'brackets'=> '括弧',
			),
		) );
		$wp_customize->add_setting( 'nmd_heading_h4', array(
			'type'				=> 'option',
			'default'			=> 'default',
			'sanitize_callback'	=> 'nmd_sanitize_select',
		) );
		$wp_customize->add_control( 'nmd_heading_h4', array(
			'label'		=> '記事内h4見出しのスタイル',
			'section'	=> 'section_heading',
			'settings'	=> 'nmd_heading_h4',
			'type'		=> 'select',
			'choices'	=> array(
				'default' => '装飾なし',
				'bg-color' => '背景カラー',
				'left-line' => '左線',
				'left-line-bg-color' => '左線＋背景色',
				'under-line' => '下線',
				'top-under-line' => '上線＋下線',
				'arrow' => '矢印＋サークル',
				'double-line' => '二重線',
				'marker' => 'マーカー',
				'fold' => '折込み',
				'speech-bubble' => '吹き出し＋背景色',
				'speech-bubble-border'=> '吹き出し＋枠線',
				'speech-bubble-under-line'=> '吹き出し＋下線',
				'brackets'=> '括弧',
			),
		) );
		$wp_customize->add_setting( 'nmd_heading_h5', array(
			'type'				=> 'option',
			'default'			=> 'default',
			'sanitize_callback'	=> 'nmd_sanitize_select',
		) );
		$wp_customize->add_control( 'nmd_heading_h5', array(
			'label'		=> '記事内h5見出しのスタイル',
			'section'	=> 'section_heading',
			'settings'	=> 'nmd_heading_h5',
			'type'		=> 'select',
			'choices'	=> array(
				'default' => '装飾なし',
				'bg-color' => '背景カラー',
				'left-line' => '左線',
				'left-line-bg-color' => '左線＋背景色',
				'under-line' => '下線',
				'top-under-line' => '上線＋下線',
				'arrow' => '矢印＋サークル',
				'double-line' => '二重線',
				'marker' => 'マーカー',
				'fold' => '折込み',
				'speech-bubble' => '吹き出し＋背景色',
				'speech-bubble-border'=> '吹き出し＋枠線',
				'speech-bubble-under-line'=> '吹き出し＋下線',
				'brackets'=> '括弧',
			),
		) );
		$wp_customize->add_setting( 'nmd_heading_h6', array(
			'type'				=> 'option',
			'default'			=> 'default',
			'sanitize_callback'	=> 'nmd_sanitize_select',
		) );
		$wp_customize->add_control( 'nmd_heading_h6', array(
			'label'		=> '記事内h6見出しのスタイル',
			'section'	=> 'section_heading',
			'settings'	=> 'nmd_heading_h6',
			'type'		=> 'select',
			'choices'	=> array(
				'default' => '装飾なし',
				'bg-color' => '背景カラー',
				'left-line' => '左線',
				'left-line-bg-color' => '左線＋背景色',
				'under-line' => '下線',
				'top-under-line' => '上線＋下線',
				'arrow' => '矢印＋サークル',
				'double-line' => '二重線',
				'marker' => 'マーカー',
				'fold' => '折込み',
				'speech-bubble' => '吹き出し＋背景色',
				'speech-bubble-border'=> '吹き出し＋枠線',
				'speech-bubble-under-line'=> '吹き出し＋下線',
				'brackets'=> '括弧',
			),
		) );
		/**
		 * シェアボタン
		 */
		$wp_customize->add_section( 'nmd_section_share_btn', array(
			'title'			=> 'シェアボタン',
			'panel'			=> 'nmd_postpage_panel',
			'description'	=> 'シェアボタンの設定ができます。'
		) );
		$wp_customize->add_setting( 'nmd_share_btn_position', array(
			'sanitize_callback' => 'nmd_no_sanitize',
		) );
		$wp_customize->add_control( new Nmd_Custom_Title( $wp_customize, 'nmd_share_btn_position', array(
			'section' => 'nmd_section_share_btn',
			'label'   => 'シェアボタンの表示',
		) ) );
		// 記事上
		$wp_customize->add_setting( 'nmd_share_btn_entry_top', array(
			'sanitize_callback' => 'nmd_sanitize_checkbox',
			'default'			=> 'checked',
		) );
		$wp_customize->add_control( 'nmd_share_btn_entry_top', array(
			'section'	=> 'nmd_section_share_btn',
			'settings'	=> 'nmd_share_btn_entry_top',
			'label'		=> '記事上にシェアボタンを表示',
			'type'		=> 'checkbox',
		) );
		$wp_customize->selective_refresh->add_partial( 'nmd_share_btn_entry_top', array(
			'selector' => '.share-post',
		) );
		// 記事下
		$wp_customize->add_setting( 'nmd_share_btn_entry_bottom', array(
			'sanitize_callback' => 'nmd_sanitize_checkbox',
			'default'			=> 'checked',
		) );
		$wp_customize->add_control( 'nmd_share_btn_entry_bottom', array(
			'section'	=> 'nmd_section_share_btn',
			'settings'	=> 'nmd_share_btn_entry_bottom',
			'label'		=> '記事下にシェアボタンを表示',
			'type'		=> 'checkbox',
		) );
		$wp_customize->add_setting('nmd_hide_share_btn_page_title', array(
			'sanitize_callback'	=> 'nmd_no_sanitize',
		));
		$wp_customize->add_control(new Nmd_Custom_Title($wp_customize, 'nmd_hide_share_btn_page_title', array(
			'section'	=> 'nmd_section_share_btn',
			'label'		=> '固定ページでシェアボタンを非表示にする',
		)));
		$wp_customize->add_setting('nmd_hide_share_btn_page', array(
			'type'				=> 'option',
			'sanitize_callback'	=> 'nmd_sanitize_checkbox',
		));
		$wp_customize->add_control('nmd_hide_share_btn_page', array(
			'section'	=> 'nmd_section_share_btn',
			'settings'	=> 'nmd_hide_share_btn_page',
			'label'		=> '固定ページで非表示',
			'type'		=> 'checkbox',
		));
		/**
		 * 表示するシェアボタン
		 */
		$wp_customize->add_setting( 'nmd_share_btn_service', array(
			'sanitize_callback' => 'nmd_no_sanitize',
		) );
		$wp_customize->add_control( new Nmd_Custom_Title( $wp_customize, 'nmd_share_btn_service', array(
			'section' => 'nmd_section_share_btn',
			'label'   => '表示するシェアボタン',
		) ) );
		// Facebook
		$wp_customize->add_setting('nmd_share_facebook', array(
			'default'			=> 'checked',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		));
		$wp_customize->add_control('nmd_share_facebook', array(
			'section'	=> 'nmd_section_share_btn',
			'settings'	=> 'nmd_share_facebook',
			'label'		=> 'Facebookのシェアボタンを表示',
			'type'		=> 'checkbox',
		));
		//Twitter
		$wp_customize->add_setting( 'nmd_share_twitter', array(
			'default'			=> 'checked',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_share_twitter', array(
			'section'	=> 'nmd_section_share_btn',
			'settings'	=> 'nmd_share_twitter',
			'label'		=> 'Twitterのシェアボタンを表示',
			'type'		=> 'checkbox',
		) );
		// Pocket
		$wp_customize->add_setting('nmd_share_pocket', array(
			'default'			=> 'checked',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		));
		$wp_customize->add_control('nmd_share_pocket', array(
			'section'	=> 'nmd_section_share_btn',
			'settings'	=> 'nmd_share_pocket',
			'label'		=> 'Pocketのシェアボタンを表示',
			'type'		=> 'checkbox',
		));
		// LINE
		$wp_customize->add_setting('nmd_share_line', array(
			'default'			=> 'checked',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		));
		$wp_customize->add_control('nmd_share_line', array(
			'section'	=> 'nmd_section_share_btn',
			'settings'	=> 'nmd_share_line',
			'label'		=> 'LINEのシェアボタンを表示',
			'type'		=> 'checkbox',
		));
		// Pinterest
		$wp_customize->add_setting('nmd_share_pinterest', array(
			'default'			=> 'checked',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		));
		$wp_customize->add_control('nmd_share_pinterest', array(
			'section'	=> 'nmd_section_share_btn',
			'settings'	=> 'nmd_share_pinterest',
			'label'		=> 'Pinterestのシェアボタンを表示',
			'type'		=> 'checkbox',
		));
		// Hatena bookmark
		$wp_customize->add_setting( 'nmd_share_hatebu', array(
			'default'			=> 'checked',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_share_hatebu', array(
			'section'	=> 'nmd_section_share_btn',
			'settings'	=> 'nmd_share_hatebu',
			'label'		=> 'はてなブックマークのシェアボタンを表示',
			'type'		=> 'checkbox',
		) );
		/**
		 * 投稿者情報の設定
		 */
		$wp_customize->add_section( 'nmd_section_post_author', array(
			'title'			=> '投稿者情報の設定',
			'panel'			=> 'nmd_postpage_panel',
			'description'	=> '投稿者情報に関する設定'
		) );
		$wp_customize->add_setting( 'nmd_display_author_info', array(
			'sanitize_callback'	=> 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_display_author_info', array(
			'label'			=> '投稿者情報を表示する',
			'description'	=> '「ユーザー」の各ユーザーページにて入力した情報を記事下に表示させます。',
			'section'		=> 'nmd_section_post_author',
			'settings'		=> 'nmd_display_author_info',
			'type'			=> 'checkbox',
		) );
		$wp_customize->selective_refresh->add_partial( 'nmd_display_author_info', array(
			'selector' => '#writer',
		) );
	}
	add_action( 'customize_register', 'nmd_customizer_register_post' );
}
