<?php

/**
 * 目次関連設定
 */
if (!defined('ABSPATH')) {
	exit;
}

function nmd_add_toc_fields()
{
	add_meta_box('toc_setting', '目次の非表示設定', 'nmd_insert_toc_fields', array('post', 'page'), 'side');
}
add_action('admin_menu', 'nmd_add_toc_fields');

// カスタムフィールドの入力エリア
function nmd_insert_toc_fields()
{

	global $post;

	if (get_post_meta($post->ID, 'toc_hide', true) == "1") {
		$toc_hide_check = "checked";
	} else {
		$toc_hide_check = "";
	}

?>
	<label>
		<input type="checkbox" name="toc_hide" value="1" <?php echo $toc_hide_check; ?>>この投稿で目次を非表示にする。
	</label>
<?php
}

// カスタムフィールドの値を保存
function nmd_save_toc_fields($post_id)
{
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return $post_id;

	if (isset($_POST['toc_hide']) && $_POST['toc_hide'] === '') {
		delete_post_meta($post_id, 'toc_hide');
	} elseif (!empty($_POST['toc_hide'])) {
		update_post_meta($post_id, 'toc_hide', $_POST['toc_hide']);
	} elseif (!isset($_POST['toc_hide'])) {
		delete_post_meta($post_id, 'toc_hide');
	} else {
		$value = '';
	}
}
add_action('save_post', 'nmd_save_toc_fields');

/**
 * 同じ見出しがあると不具合が起こるのでコメントアウトで対処
 */
function nmd_replace_same_heading($content)
{

	$toc_heading_num = get_option('nmd_toc_heading_num', '3');

	if (preg_match_all('/<h([1-' . $toc_heading_num . '])[^>]*>(.*?)<\/h\1>/', $content, $matches,  PREG_SET_ORDER)) {

		$cnt = 0;

		foreach ($matches as $match) {

			$heaging_text = str_replace('/', '\/', $match[2]);
			$heaging_text = str_replace('(', '\(', $heaging_text);
			$heaging_text = str_replace(')', '\)', $heaging_text);
			$heaging_text = str_replace('.', '\.', $heaging_text);
			$heaging_text = str_replace('|', '\|', $heaging_text);
			$heaging_text = str_replace('\\', '\\', $heaging_text);
			$heaging_text = str_replace('[', '\[', $heaging_text);
			$heaging_text = str_replace(']', '\]', $heaging_text);
			$heaging_text = str_replace('{', '\{', $heaging_text);
			$heaging_text = str_replace('}', '\}', $heaging_text);
			$heaging_text = str_replace('$', '\$', $heaging_text);
			$heaging_text = str_replace('*', '\*', $heaging_text);

			$content = preg_replace('/<h([1-' . $toc_heading_num . '])([^>]*)>' . $heaging_text . '<\/h\1>/', '<h$1$2>' . $match[2] . '<!--' . $cnt . '--></h$1>', $content, 1);

			$cnt++;
		}
	}

	return $content;
}

function nmd_get_toc_info($content)
{

	$toc = '';
	$counter = 0;

	$toc_heading_num = get_option('nmd_toc_heading_num', '3');

	// 記事内の見出しを検索
	if (preg_match_all('/<h([1-' . $toc_heading_num . '])[^>]*>(.*?)<\/h\1>/', $content, $matches,  PREG_SET_ORDER)) {

		$min_level = min(array_map(function ($m) {
			return $m[1];
		}, $matches));

		$current_level = $min_level - 1;

		$sub_levels = array('1' => 0, '2' => 0, '3' => 0, '4' => 0, '5' => 0, '6' => 0);

		foreach ($matches as $m) {
			$level = $m[1];
			$text = $m[2];

			while ($current_level > $level) {
				$current_level--;
				$toc .= '</li></ol>';
			}

			if ($current_level == $level) {
				$toc .= '</li><li class="nmd-toc__item">';
			} else {

				while ($current_level < $level) {
					$current_level++;
					$toc .= sprintf('<ol class="nmd-toc__list toc__list-%s"><li class="nmd-toc__item">', $current_level);
				}
				for ($idx = $current_level + 0; $idx < count($sub_levels); $idx++) {
					$sub_levels[$idx] = 0;
				}
			}

			$sub_levels[$current_level]++;

			$level_fullpath = array();
			for ($idx = $min_level; $idx <= $level; $idx++) {
				$level_fullpath[] = $sub_levels[$idx];
			}
			$target_anchor = 'toc__' . implode('_', $level_fullpath);

			$toc .= sprintf('<a class="nmd-toc__link" href="#%s">%s</a>', $target_anchor, strip_tags($text));

			$hid = preg_replace('/<h([1-6])([^>]*)>(.*?)<\/h\1>/', '<h\1\2>\3</h\1><span class="nmd-toc-target" id="' . $target_anchor . '"></span>', $m[0]);
			// $hid = preg_replace('/<h([1-6])/', '<h\1 id="' .$target_anchor . '"', $m[0]);
			$content = str_replace($m[0], $hid, $content);
		}

		while ($current_level >= $min_level) {
			$toc .= '</li></ol>';
			$current_level--;
		}

		$counter = count($matches);
	}
	return array('content' => $content, 'toc' => $toc, 'count' => $counter);
}

//目次を作成します。
function nmd_add_toc($content)
{

	if (empty(get_option('nmd_toc_auto')) && strpos($content, '[toc]') === false)
		return $content;

	if (get_post_meta(get_the_ID(), 'toc_hide', true) === '1')
		return $content;

	// 目次を表示するために必要な見出しの数
	$number = get_option('nmd_toc_number', 1);
	$content = nmd_replace_same_heading($content);
	// 目次関連の情報を取得します。
	$toc_info = nmd_get_toc_info($content);
	$content = $toc_info['content'];
	$toc = $toc_info['toc'];
	$count   = $toc_info['count'];

	if (get_option('nmd_toc_close')) {
		$close = "";
	} else {
		$close = "checked";
	}

	$toc_title = get_option('nmd_toc_title', '目次');

	//すでに目次がある場合は削除（ショートコードで生成されてしまうため）
	$pattern = '/<!-- start_toc -->(.*?)<!-- end_toc -->/s';
	$content = preg_replace($pattern, '', $content);

	$shortcode_toc = '[toc]';
	$toc_class = !empty(get_option('nmd_toc_numbering')) ? ' nmd-toc--numbering' : '';
	if ($toc != '' && $count >= $number) {
		// 目次を装飾
		$decorated_toc = sprintf('
		<!-- start_toc --><div class="nmd-toc' . $toc_class . '" id="nmd-toc">
            <div class="nmd-toc__title-box">
			<!-- input class="nmd-toc__toggle" id="toc__toggle" type="checkbox" ' . $close . ' -->
			<div class="nmd-toc__top">
			<div class="nmd-toc__title">' . $toc_title . '</div>
			<label class="nmd-toc__switch" for="toc__toggle"></label>
			</div>
		%s
		</div>
        </div><!-- end_toc -->', $toc);

		if (is_singular()) {
			if (strpos($content, $shortcode_toc) !== false) {
				$content = str_replace($shortcode_toc, $decorated_toc, $content);
			} else if (get_post_meta(get_the_ID(), 'toc_hide', true) != '1' && get_option('nmd_toc_auto') && preg_match('/<h[1-6].*>/', $content, $matches, PREG_OFFSET_CAPTURE)) {

				$pos = $matches[0][1];
				$content = substr($content, 0, $pos) . $decorated_toc . substr($content, $pos);
			}
		}
	} else {
		$content = str_replace($shortcode_toc, '', $content);
	}
	return $content;
}
add_filter('the_content', 'nmd_add_toc', 100);
